#****************************************************************************
#
#  Module: ImportReportsOperationsManagerDW.ps1
#
#  Purpose: Setup secRMM reports in SCOM DW SSRS.
#
#  Copyright (c) 2019 Squadra Technologies 
#   
#****************************************************************************
#For SSRS Properties, 
#see http://msdn.microsoft.com/en-us/library/ms152826(v=sql.90).aspx

cls
$ServerRunningSSRS = "localhost";
$ReportFolderName = "Removable Media Security"; 
$ReportFolderDescription = "Reports for Removable Media provided by the product secRMM";
$ReportNameFilter = "*.rdl"; #"secRMM_*_OperationsManagerDW.rdl";

$SharedDatasourceReferencePath = "/Data Warehouse Main";

$SourceDirectory = Split-Path $script:MyInvocation.MyCommand.Path;
$ReportServerUri  = "http://" + $ServerRunningSSRS + "/ReportServer/ReportService2010.asmx";
$ReportServerWebServiceProxy = New-WebServiceProxy -Uri $ReportServerUri -UseDefaultCredential;
$ReportServerWebServiceProxyNamespace = $ReportServerWebServiceProxy.GetType().Namespace;

$TypeProperty = ($ReportServerWebServiceProxyNamespace + '.Property');
 
$ReportFolderPropertyDescription = New-Object ($TypeProperty);
$ReportFolderPropertyDescription.Name = "Description";
$ReportFolderPropertyDescription.Value = $ReportFolderDescription;
 
#$ReportFolderName = $ReportFolderName + " " + (Get-Date -format "yyyy-MMM-dd-hhmmtt");
 
$NumberOfProperties = 1;
$ReportFolderProperties = New-Object ($TypeProperty + '[]')$NumberOfProperties; 
$ReportFolderProperties[0] = $ReportFolderPropertyDescription;

$Errors = @();

#Create Report Folder
$ReportFolder = $null;
try
{
    $ReportFolder = $ReportServerWebServiceProxy.CreateFolder($ReportFolderName, "/", $ReportFolderProperties);
    Write-Host "Folder `"$ReportFolderName`" Created";
}
catch [System.Web.Services.Protocols.SoapException]
{
    if ($_.Exception.Detail.InnerText -match "rsItemAlreadyExists400")
    {
        Write-Host "Folder: $ReportFolderName already exists.";
    }
    else
    {
        $msg = "Error creating folder: $ReportFolderName. Msg: '{0}'" -f $_.Exception.Detail.InnerText;
        Write-Error $msg;
		$Errors += $msg;
    }
}

if ($ReportFolder -ne $null) {
	#Upload Reports into Report Folder
	$ReportPath = "/" + $ReportFolderName;
	ForEach ($RdlFile in Get-ChildItem $SourceDirectory -Filter $ReportNameFilter )
	{
		#Write-Host $RdlFile
		$Report = $null;
		try
		{
			 $RdlFileName = $RdlFile.Name

			#Get Report content in bytes
			$byteArray = Get-Content $RdlFile.FullName -encoding byte
			$msg = "Size: {0} KB" -f "{0:N0}" -f ($byteArray.Length/1KB) 
 
			#Call Proxy to upload report  
			$warnings =@();
			$Report = $ReportServerWebServiceProxy.CreateCatalogItem("Report", $RdlFileName,$ReportPath,$overwrite,$byteArray,$property,[ref]$warnings);
			if($warnings.Length -le 1) 
			{ 
				Write-Host "Report" $RdlFileName "uploaded successfully." -ForegroundColor White; 
			}
			else 
			{
				$WarningCount = 0;
				foreach ($message in $warnings)
				{
					if (($message.Code -ne "rsDataSourceReferenceNotPublished") -and
						($message.Code -ne "rsOverlappingReportItems"))
					{
						write-host "$($message.Severity) $($message.Code) $($message.Message)" -ForegroundColor Yellow;
						$WarningCount++;
					}
				}

				if ($WarningCount -eq 0)
				{
					Write-Host "Report" $RdlFileName "uploaded successfully." -ForegroundColor White; 
				}
			}
		}
		catch [System.IO.IOException]
		{
			$msg = "Error while reading rdl file : '{0}', Message: '{1}'" -f $RdlFile, $_.Exception.Message;
			Write-Error $msg;
			$Errors += $msg;
		}
		catch [System.Web.Services.Protocols.SoapException]
		{
			if ($_.Exception.Detail.InnerText -match 'rsItemAlreadyExists400')
			{
				Write-Host "Report: $RdlFileName already exists." -ForegroundColor Red;
			}
			else
			{
				$msg = "Error uploading report: $RdlFileName. Msg: '{0}' " -f $_.Exception.Detail.InnerText;
				Write-Error $msg;
				$Errors += $msg;
			}
		}

		#Set the reports SSRS DataSource
		if ($Report -ne $null) {
			$referencedDataSourceName = (@($ReportServerWebServiceProxy.GetItemReferences($report.Path, "DataSource")))[0].Name;
			$dataSource = New-Object ("$ReportServerWebServiceProxyNamespace.DataSource"); 
			$dataSource.Name = $referencedDataSourceName;
			$dataSource.Item = New-Object ("$ReportServerWebServiceProxyNamespace.DataSourceReference");
			$dataSource.Item.Reference = $SharedDatasourceReferencePath;
			$ReportServerWebServiceProxy.SetItemDataSources($report.Path, $dataSource);
		}
	}
}

if ($Errors.Length -eq 0)
{
	Write-Host "Import of reports completed." -ForegroundColor White;
}
# SIG # Begin signature block
# MIINVgYJKoZIhvcNAQcCoIINRzCCDUMCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUCYBcEV/yusfiVZDvOSj32GdF
# yOSgggqUMIIFPTCCBCWgAwIBAgIQAwzCszxrLQTfnUpB4z2unDANBgkqhkiG9w0B
# AQsFADB2MQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYD
# VQQLExB3d3cuZGlnaWNlcnQuY29tMTUwMwYDVQQDEyxEaWdpQ2VydCBTSEEyIEhp
# Z2ggQXNzdXJhbmNlIENvZGUgU2lnbmluZyBDQTAeFw0yMDA0MDIwMDAwMDBaFw0y
# MzAzMDgxMjAwMDBaMHwxCzAJBgNVBAYTAlVTMQ8wDQYDVQQIEwZOZXZhZGExEjAQ
# BgNVBAcTCUxhcyBWZWdhczEjMCEGA1UEChMaU3F1YWRyYSBUZWNobm9sb2dpZXMs
# IExMQy4xIzAhBgNVBAMTGlNxdWFkcmEgVGVjaG5vbG9naWVzLCBMTEMuMIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAye9LDIQiPPVFIziY8lf1dtbpYf0P
# 1N2rilQ3GExOuI7NrsYhNbdkeNUgZdUpPhyLlaDBpFkr4EV+xVDCpS8gRN2FlHdA
# /7+eBTM3tWXpCx1Om0ttetx070NhnespzKXq6wJGoCWLN0Z3qrk+s31GUepdoCrK
# v8oCi47l8GQsga7ThWbgkHIUBwEtNKJ3ylZ5hJsgqfwHNsU+dt9+MXxfE+UVMtJH
# OcrR9P5ddacXmYebYwKGlNv1V5VIkeS30JMUFOHLqoNzuvEP0QV+Tm3rH9JcSyS2
# XHTb9c0T3ivdlxkhjALHa4U9NOlIK73genbcSdZukEzDSvYp209tgh5WcQIDAQAB
# o4IBvzCCAbswHwYDVR0jBBgwFoAUZ50PIAkMzIo65YJGcmL88cyQ5UAwHQYDVR0O
# BBYEFFh0bb6mInA9+qrvaDn0mHzwxIIaMA4GA1UdDwEB/wQEAwIHgDATBgNVHSUE
# DDAKBggrBgEFBQcDAzBtBgNVHR8EZjBkMDCgLqAshipodHRwOi8vY3JsMy5kaWdp
# Y2VydC5jb20vc2hhMi1oYS1jcy1nMS5jcmwwMKAuoCyGKmh0dHA6Ly9jcmw0LmRp
# Z2ljZXJ0LmNvbS9zaGEyLWhhLWNzLWcxLmNybDBMBgNVHSAERTBDMDcGCWCGSAGG
# /WwDATAqMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy5kaWdpY2VydC5jb20vQ1BT
# MAgGBmeBDAEEATCBiAYIKwYBBQUHAQEEfDB6MCQGCCsGAQUFBzABhhhodHRwOi8v
# b2NzcC5kaWdpY2VydC5jb20wUgYIKwYBBQUHMAKGRmh0dHA6Ly9jYWNlcnRzLmRp
# Z2ljZXJ0LmNvbS9EaWdpQ2VydFNIQTJIaWdoQXNzdXJhbmNlQ29kZVNpZ25pbmdD
# QS5jcnQwDAYDVR0TAQH/BAIwADANBgkqhkiG9w0BAQsFAAOCAQEAg1EHEylJdXEQ
# I4GCja7tnrQ/IFUPkIdm+EaPkoxsHS8U6/bcqsQdHyPClX8S0Bt34jPWbVqRD3Ks
# koHDF5xkVC9gO8b2b2BT0WgTun7UBaz6vIJDmUy4GybC4BXgboEvnwHIN7GGMjht
# QoeS9vb2XIhDLpGD+smsgGdLqpjIR9odR5fmXiXT6LPF2mgYNDSlpnfNj7vwjPFR
# CnMtqVM4Ln0UufFvAP3wmvgSBjV58D54NH+5iRbU6zEE+T5A6WpWjldLoyryrB6e
# AKna0qEix0DpgwhdVJal5Dn0dVzB1XiibyDKu6k5z6kzYw/uCv5vnDhGlmMEd22O
# kQK+jmsKVTCCBU8wggQ3oAMCAQICEAt+EJA8OEkP+i9nmoehp7kwDQYJKoZIhvcN
# AQELBQAwbDELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcG
# A1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTErMCkGA1UEAxMiRGlnaUNlcnQgSGlnaCBB
# c3N1cmFuY2UgRVYgUm9vdCBDQTAeFw0xMzEwMjIxMjAwMDBaFw0yODEwMjIxMjAw
# MDBaMHYxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNV
# BAsTEHd3dy5kaWdpY2VydC5jb20xNTAzBgNVBAMTLERpZ2lDZXJ0IFNIQTIgSGln
# aCBBc3N1cmFuY2UgQ29kZSBTaWduaW5nIENBMIIBIjANBgkqhkiG9w0BAQEFAAOC
# AQ8AMIIBCgKCAQEAtEpefQcPQd7E9XYWNr1x/88/T3NLnNEN/krLV1hehRbdAhVU
# mfCPPC9NAngQaMjYNUs/wfdnzpgcrjO5LR2kClSTxIWi3zWx9fE8p7M0+11IyUbJ
# YkS8SJnrKElTwz2PwA7eNZjpYlHfPWtAYe4EQdrPp1xWltH5TLdEhIeYaeWCuRPm
# Vb/IknCSCjFvf4syq89rWp9ixD7uvu1ZpFN/C/FSiIp7Cmcky5DN7NJNNEyw4bWf
# nMb2byzN5spTdAGfZzXeOEktzu05RIIZeU4asrX7u3jwSWanz/pclnWSixpy2f9Q
# klPMPsJDMgkahhNpPPuBMjMyZHVzKCYdCDA7BwIDAQABo4IB4TCCAd0wEgYDVR0T
# AQH/BAgwBgEB/wIBADAOBgNVHQ8BAf8EBAMCAYYwEwYDVR0lBAwwCgYIKwYBBQUH
# AwMwfwYIKwYBBQUHAQEEczBxMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdp
# Y2VydC5jb20wSQYIKwYBBQUHMAKGPWh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNv
# bS9EaWdpQ2VydEhpZ2hBc3N1cmFuY2VFVlJvb3RDQS5jcnQwgY8GA1UdHwSBhzCB
# hDBAoD6gPIY6aHR0cDovL2NybDQuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0SGlnaEFz
# c3VyYW5jZUVWUm9vdENBLmNybDBAoD6gPIY6aHR0cDovL2NybDMuZGlnaWNlcnQu
# Y29tL0RpZ2lDZXJ0SGlnaEFzc3VyYW5jZUVWUm9vdENBLmNybDBPBgNVHSAESDBG
# MDgGCmCGSAGG/WwAAgQwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNl
# cnQuY29tL0NQUzAKBghghkgBhv1sAzAdBgNVHQ4EFgQUZ50PIAkMzIo65YJGcmL8
# 8cyQ5UAwHwYDVR0jBBgwFoAUsT7DaQP4v0cB1JgmGggC72NkK8MwDQYJKoZIhvcN
# AQELBQADggEBAGoO/34TfAalS8AujPlTZAniuliRMFDszJ/h06gvSEY2GCnQeChf
# mFZADx66vbE7h1zcW9ggDe0aFk3VESQhS/EnaZAT6xGhAdr9tU55WXW9OCpqw/aO
# QSuKoovXLFFR2ZygyONOumyoR9JO0WgfjAJXO7Mpao5qICq58gBiZLrI6QD5zKTU
# upo12K8sZWwWfFgh3kow0PrrJF0GyZ0Wt61KRdMl4gzwQKpcTax+zQaCuXZGaQjY
# MraC/uOpWDRDG45nZ5c/aDEWNjiVPof3x8OvnXp3Gdnek7X9biv8lPk9t0wSNSww
# vuiNngVwmkgT9IzW5x6sOOeo860Mt3rsZ+0xggIsMIICKAIBATCBijB2MQswCQYD
# VQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3d3cuZGln
# aWNlcnQuY29tMTUwMwYDVQQDEyxEaWdpQ2VydCBTSEEyIEhpZ2ggQXNzdXJhbmNl
# IENvZGUgU2lnbmluZyBDQQIQAwzCszxrLQTfnUpB4z2unDAJBgUrDgMCGgUAoHgw
# GAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG9w0BCQMxDAYKKwYBBAGC
# NwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkqhkiG9w0BCQQx
# FgQUQFOZkjDTBupIqqwUWLkOjZ3nxUAwDQYJKoZIhvcNAQEBBQAEggEAgb49n73b
# FgigJj6R3WJ2libeFFzHXyxCxjLUKAv3r5cBxGivPh4coQO70crJzzj1mwe4llr+
# ogBCcgeHOE2/he+Kz2V/f/2+dQlg6QdLqG/YFWsPpF2oGDZaMFVv6RWu3gAmtW4C
# +ao1S8VuC1aUJ4PrIdVBuIOxPhenU2ZyYaxpb4X0UnvVvKNwVpTVPMEu49RpEyH8
# rVlwXvdnfL4cC7ixpxBYV+bSCI/IumduxujSdihuMEkN8E5YQle1JREq1SxPy0ET
# IL1PDx7V/U33D6tWClVS+ILqIvBITcJwqS1Ppyf8kX54yAHFLhjzFs389xnZDXZB
# UcH2VdFQPYCoMw==
# SIG # End signature block
